@@ -105,13 +105,13 @@
 #include <ctype.h>
 #include <signal.h>
 
-static int connect;
+static int myconnection;
 static sigjmp_buf env_alrm;
 static void
 no_hang(int sig)
   {
   fprintf(stderr, "xpbs_datadump: alarm timed-out\n");
-  connect = 0; /* connection to server  has failed */
+  myconnection = 0; /* connection to server  has failed */
   siglongjmp(env_alrm, 1);
   }
 
@@ -1194,7 +1194,7 @@ display_statserver(struct batch_status *status, int prtheader, int full, int nod
   }
 
 static int
-getNumNodesInUse(int connect)
+getNumNodesInUse(int myconnection)
   {
 
   struct batch_status *j_status;
@@ -1211,13 +1211,13 @@ getNumNodesInUse(int connect)
   int  nodes;
 
   set_attrop(&run_list, ATTR_state, (char *)NULL, "R", EQ);
-  j_status = pbs_selstat(connect, run_list, NULL);
+  j_status = pbs_selstat(myconnection, run_list, NULL);
 
   if (j_status == NULL)
     {
     if (pbs_errno != PBSE_NONE)
       {
-      errmsg = pbs_geterrmsg(connect);
+      errmsg = pbs_geterrmsg(myconnection);
 
       if (errmsg != NULL)
         {
@@ -1614,28 +1614,28 @@ main(  /* qstat */
     if (sigsetjmp(env_alrm, 1) == 0)
       {
       alarm(timeout_secs);
-      connect = cnt2server(server_out);
+      myconnection = cnt2server(server_out);
       }
 
     alarm(0);
 
-    if (connect <= 0)
+    if (myconnection <= 0)
       {
-      fprintf(stderr, "xpbs_datadump: Can not connect to server %s (%d)\n",
+      fprintf(stderr, "xpbs_datadump: Can not myconnection to server %s (%d)\n",
               server_out, pbs_errno);
-      any_failed = connect;
+      any_failed = myconnection;
       continue;
       }
 
     /* Get server information */
-    p_status = pbs_statserver(connect, NULL, NULL);
+    p_status = pbs_statserver(myconnection, NULL, NULL);
 
     if (p_status == NULL)
       {
 
       if (pbs_errno)
         {
-        errmsg = pbs_geterrmsg(connect);
+        errmsg = pbs_geterrmsg(myconnection);
 
         if (errmsg != NULL)
           {
@@ -1656,20 +1656,20 @@ main(  /* qstat */
       if (!do_job_only && !do_trackjob_only)
         {
         display_statserver(p_status, TRUE, FALSE,
-                           getNumNodesInUse(connect));
+                           getNumNodesInUse(myconnection));
         }
 
       pbs_statfree(p_status);
       }
 
     /* Get the queue information */
-    p_status = pbs_statque(connect, queue_name_out, NULL, NULL);
+    p_status = pbs_statque(myconnection, queue_name_out, NULL, NULL);
 
     if (p_status == NULL)
       {
       if (pbs_errno)
         {
-        errmsg = pbs_geterrmsg(connect);
+        errmsg = pbs_geterrmsg(myconnection);
 
         if (errmsg != NULL)
           {
@@ -1696,13 +1696,13 @@ main(  /* qstat */
     /*
     ### Get Jobs summary info information for each of the servers
     */
-    p_status = pbs_selstat(connect, select_list, NULL);
+    p_status = pbs_selstat(myconnection, select_list, NULL);
 
     if (p_status == NULL)
       {
       if (pbs_errno != PBSE_NONE)
         {
-        errmsg = pbs_geterrmsg(connect);
+        errmsg = pbs_geterrmsg(myconnection);
 
         if (errmsg != NULL)
           {
@@ -1730,7 +1730,7 @@ main(  /* qstat */
       pbs_statfree(p_status);
       }
 
-    pbs_disconnect(connect);
+    pbs_disconnect(myconnection);
     }
 
   exit(any_failed);
