@@ -365,7 +365,7 @@ int DIS_tcp_wflush(
   {
   size_t ct;
   int  i;
-  char *pb;
+  char *pb = NULL;
 
   struct tcpdisbuf *tp;
 
@@ -649,9 +649,9 @@ static int tcp_puts(
   char *id = "tcp_puts";
 #endif
 
-  struct tcp_chan *tcp;
-  struct tcpdisbuf *tp;
-  char *temp;
+  struct tcp_chan *tcp = NULL;
+  struct tcpdisbuf *tp = NULL;
+  char *temp = NULL;
   int leadpct, trailpct; 
   size_t newbufsize;
 
@@ -790,6 +790,34 @@ DIS_tcp_funcs(void)
   return;
   }
 
+void DIS_tcp_close(
+
+  int fd)
+
+  {
+  struct tcp_chan *tcp;
+
+  /* On startup tcparray may not yet be initialized. check it */
+  if (tcparray == NULL)
+    return;
+
+  if (fd > tcparraymax)
+    return;
+
+  tcp = tcparray[fd];
+  if (tcp != NULL)
+    {
+    if (tcp->readbuf.tdis_thebuf != NULL)
+      free(tcp->readbuf.tdis_thebuf);
+    if (tcp->writebuf.tdis_thebuf != NULL)
+      free(tcp->writebuf.tdis_thebuf);
+
+    free(tcp);
+    tcparray[fd] = NULL;
+    }
+
+  return;
+  }
 
 
 
@@ -808,8 +836,8 @@ void DIS_tcp_setup(
   int fd)
 
   {
-  struct tcp_chan *tcp;
-  struct tcpdisbuf *tp;
+  struct tcp_chan *tcp = NULL;
+  struct tcpdisbuf *tp = NULL;
 
   /* check for bad file descriptor */
 
@@ -848,6 +876,7 @@ void DIS_tcp_setup(
 
     if (tcparray == NULL)
       {
+      /* Remember calloc will initialize memory to 0 */
       tcparray = (struct tcp_chan **)calloc(
         tcparraymax,
         sizeof(struct tcp_chan *));
@@ -890,6 +919,8 @@ void DIS_tcp_setup(
     {
     tcparray[fd] = (struct tcp_chan *)malloc(sizeof(struct tcp_chan));
 
+    memset(tcparray[fd], 0, sizeof(struct tcp_chan));
+
     tcp = tcparray[fd];
 
     if (tcp == NULL)
@@ -899,6 +930,7 @@ void DIS_tcp_setup(
       return;
       }
 
+    /* Setting up the read buffer */
     tp = &tcp->readbuf;
 
     tp->tdis_thebuf = (char *)malloc(THE_BUF_SIZE);
@@ -908,8 +940,12 @@ void DIS_tcp_setup(
 
       return;
       }
+
+    memset(tp->tdis_thebuf, 0, THE_BUF_SIZE);
+
     tp->tdis_bufsize = THE_BUF_SIZE;
 
+    /* Setting up the write buffer */
     tp = &tcp->writebuf;
 
     tp->tdis_thebuf = (char *)malloc(THE_BUF_SIZE);
@@ -919,8 +955,10 @@ void DIS_tcp_setup(
 
       return;
       }
-    tp->tdis_bufsize = THE_BUF_SIZE;
 
+    memset(tp->tdis_thebuf, 0, THE_BUF_SIZE);
+
+    tp->tdis_bufsize = THE_BUF_SIZE;
 
     }
 
