@@ -105,6 +105,7 @@
 #include "pbs_error.h"
 #include "log.h"
 #include "svrfunc.h"
+#include "utils.h"
 
 #include <pwd.h>
 #include "mom_func.h"
@@ -119,6 +120,10 @@ extern int  svr_chkque(job *, pbs_queue *, char *, int, char *);
 extern int  job_route(job *);
 extern void check_state(int);
 extern void mom_server_all_update_stat();
+#ifdef NVIDIA_GPUS
+extern void mom_server_all_update_gpustat(void);
+extern int  use_nvidia_gpu;
+#endif  /* NVIDIA_GPUS */
 
 /* Global Data Items: */
 
@@ -453,7 +458,7 @@ void req_quejob(
       pj->ji_qs.ji_un.ji_newt.ji_fromaddr = get_connectaddr(sock);
       pj->ji_qs.ji_un.ji_newt.ji_scriptsz = 0;
 
-      /* Per Eric R., req_mvjobfile was giving error in open_std_file, 
+      /* Per Eric R., req_mvjobfile was giving error in open_std_file,
          showed up as fishy error message */
 
       if (pj->ji_grpcache != NULL)
@@ -736,16 +741,28 @@ void req_mvjobfile(
     return;
     }
 
-  if (((pwd = getpwnam(pj->ji_wattr[(int)JOB_ATR_euser].at_val.at_str)) == NULL) ||
-      ((fds = open_std_file(pj, jft, oflag, pwd->pw_gid)) < 0))
+  if ((pwd = getpwnam_ext(pj->ji_wattr[(int)JOB_ATR_euser].at_val.at_str)) == NULL)
     {
     /* FAILURE */
-
     req_reject(PBSE_MOMREJECT, 0, preq, NULL, "password lookup failed");
 
     return;
     }
 
+  if ((fds = open_std_file(pj, jft, oflag, pwd->pw_gid)) < 0)
+    {
+    int keeping = 1;
+    char *path = std_file_name(pj, jft, &keeping);
+
+    snprintf(log_buffer,sizeof(log_buffer),
+      "Cannot create file %s",
+      path);
+
+    req_reject(PBSE_SYSTEM, 0, preq, NULL, log_buffer);
+
+    return;
+    }
+
   if (write(
         fds,
         preq->rq_ind.rq_jobfile.rq_data,
@@ -1026,6 +1043,20 @@ void req_commit(
 
   job_save(pj, SAVEJOB_FULL);
 
+#ifdef NVIDIA_GPUS
+  /*
+   * Does this job have a gpuid assigned?
+   * if so, then update gpu status
+   */
+  if ((use_nvidia_gpu) && 
+      ((pj->ji_wattr[JOB_ATR_exec_gpus].at_flags & ATR_VFLAG_SET) != 0) &&
+      (pj->ji_wattr[JOB_ATR_exec_gpus].at_val.at_str != NULL))
+    {
+    mom_server_all_update_gpustat();
+    }
+#endif  /* NVIDIA_GPUS */
+
+
   /* NOTE: we used to flag JOB_ATR_errpath, JOB_ATR_outpath,
    * JOB_ATR_session_id, and JOB_ATR_altid as modified at this point to make sure
    * pbs_server got these attr values.  This worked fine before TORQUE modified
