@@ -123,7 +123,7 @@
 #include "../rm_dep.h"
 
 static char ident[] =
-  "@(#) unicosmk2/$RCSfile$ $Revision: 3151 $";
+  "@(#) unicosmk2/$RCSfile$ $Revision: 3230 $";
 
 #ifndef max
 #define max(a,b) (a>b ? a : b)
@@ -157,9 +157,9 @@ extern char *path_checkpoint;
 ** external functions and data
 */
 
-extern struct config  *search A_((struct config *, char *));
+extern struct config  *search(struct config *, char *);
 
-extern struct rm_attribute *momgetattr A_((char *));
+extern struct rm_attribute *momgetattr(char *);
 extern int   rm_errno;
 extern unsigned int reqnum;
 extern char   *ret_string;
@@ -173,13 +173,13 @@ extern  int     ignmem;
 /*
 ** local functions and data
 */
-static char *ncpus   A_((struct rm_attribute *attrib));
-static char *totmem  A_((struct rm_attribute *attrib));
-static char *availmem A_((struct rm_attribute *attrib));
-static char *physmem A_((struct rm_attribute *attrib));
-static char *quota  A_((struct rm_attribute *attrib));
-static char *srfs_reserve A_((struct rm_attribute *attrib));
-extern char *nullproc A_((struct rm_attribute *attrib));
+static char *ncpus(struct rm_attribute *attrib);
+static char *totmem(struct rm_attribute *attrib);
+static char *availmem(struct rm_attribute *attrib);
+static char *physmem(struct rm_attribute *attrib);
+static char *quota(struct rm_attribute *attrib);
+static char *srfs_reserve(struct rm_attribute *attrib);
+extern char *nullproc(struct rm_attribute *attrib);
 
 extern char extra_parm[];
 extern char no_parm[];
