@@ -13,10 +13,14 @@
 extern char *path_arrays;
 
 
+/* an example prototpe of an upgrade function for a specific version of the struct
+   each upgrade function should upgrade a specific version of the struct to the 
+   current version!
+int array_upgrade_v1(job_array *pa, int fds, int version, int *old_version);
+ */
+
 /* old versions of the struct.  These should have hard coded array sizes
    rather than using #defines that can change between version */
-int array_upgrade_v1(job_array *pa, int fds, int version, int *old_version);
-
 struct array_info_v1
   {
   int  struct_version;
@@ -27,6 +31,7 @@ struct array_info_v1
   char fileprefix[12];
   char submit_host[65];
   };
+  
 
 
 int array_upgrade(job_array *pa, int fds, int version, int *old_version)
@@ -41,13 +46,39 @@ int array_upgrade(job_array *pa, int fds, int version, int *old_version)
     return -1;
     }
 
-  /* call the appropriate upgrader function */
+  /* call the appropriate upgrader function, if we ever wish to depricate an old
+     array struct version, then we should delete the case from this if else-if 
+     block and delete its upgrader function */
+
+  /* version 1 is depricated, but this code is left commented out as an example 
   if (version == 1)
     {
+
     return array_upgrade_v1(pa, fds, version, old_version);
+
+    }
+   */
+  if (version < 3)
+    {
+    /* these versions are depricated, documentation includes a warning 
+       about the incompatibility and inability to upgrade, print a quick and 
+       dirty error message and exit */
+       
+    sprintf(log_buffer, "WARNING, unable to upgrade job array\n"
+            "structs from versions prior to 2.5.0.\n"
+            "Please downgrade TORQUE and upgrade once no job arrays are queued\n");
+    log_err(-1, "array_upgrade", log_buffer);
+    exit(1);
     }
   else
     {
+    if(version == 3)
+      {
+      /* Between version 3 and version 4 the element ai_qs.num_purged
+         was added. We need to account for the new element from version
+         3 arrays. */
+      return 0;
+      }
     return 1;
     }
   }
@@ -55,6 +86,12 @@ int array_upgrade(job_array *pa, int fds, int version, int *old_version)
 /* upgrader functions - upgrade from a specific version to the current version
    each time the array structure is updated these functions need to be updated */
 
+
+/* here is an example that upgraded from ai_qs version 1 to version 2
+   This version of the struct has been depricated, but this code is left here
+   as an example of an upgrade function */
+   
+/*   
 int array_upgrade_v1(job_array *pa, int fds, int version, int *old_version)
   {
 
@@ -93,3 +130,4 @@ int array_upgrade_v1(job_array *pa, int fds, int version, int *old_version)
   return 0;
 
   }
+*/
