@@ -379,6 +379,8 @@ int set_jobexid(
     }  /* END if (CheckID == 0) */
   else
     {
+    int perm;
+
     if ((attrry + (int)JOB_ATR_userlst)->at_flags & ATR_VFLAG_SET)
       pattr = attrry + (int)JOB_ATR_userlst;
     else
@@ -392,7 +394,9 @@ int set_jobexid(
       return(PBSE_BADUSER);
       }
 
-    pwent = getpwnam(puser);
+    pwent = getpwnam_ext(puser);
+
+    perm = svr_get_privilege(puser,get_variable(pjob,"PBS_O_HOST"));
 
     if (pwent == NULL)
       {
@@ -408,14 +412,15 @@ int set_jobexid(
       return(PBSE_BADUSER);
       }
 
-    if (pwent->pw_uid == 0)
+    if ((pwent->pw_uid == 0) ||
+        (perm & ATR_DFLAG_MGWR))
       {
       /* add check here for virtual user */
       if (pjob->ji_wattr[JOB_ATR_proxy_user].at_flags & ATR_VFLAG_SET)
         {
         puser = pjob->ji_wattr[JOB_ATR_proxy_user].at_val.at_str;
 
-        pwent = getpwnam(puser);
+        pwent = getpwnam_ext(puser);
 
         if (pwent == NULL)
           {
@@ -467,7 +472,7 @@ int set_jobexid(
           return(PBSE_BADUSER); /* root not allowed */
           }
         }
-      else
+      else if (pwent->pw_uid == 0)
         {
         if (EMsg != NULL)
           snprintf(EMsg, 1024, "root user %s not allowed",
@@ -551,7 +556,7 @@ int set_jobexid(
 
   if (pgrpn == NULL)
     {
-    if ((pwent != NULL) || ((pwent = getpwnam(puser)) != NULL))
+    if ((pwent != NULL) || ((pwent = getpwnam_ext(puser)) != NULL))
       {
       /* egroup not specified - use user login group */
 
