@@ -646,6 +646,8 @@ int status_nodeattrib(
       atemp[i].at_val.at_long = pnode->nd_nsn;
     else if (!strcmp((padef + i)->at_name, ATTR_NODE_note))
       atemp[i].at_val.at_str  = pnode->nd_note;
+    else if (!strcmp((padef + i)->at_name, ATTR_NODE_gpustatus))
+      atemp[i].at_val.at_arst = pnode->nd_gpustatus;
     else if (!strcmp((padef + i)->at_name, ATTR_NODE_gpus))
       {
       atemp[i].at_val.at_long  = pnode->nd_ngpus;
@@ -787,6 +789,9 @@ static void initialize_pbsnode(
   pnode->nd_nprops  = 0;
   pnode->nd_nstatus = 0;
   pnode->nd_warnbad = 0;
+  pnode->nd_ngpus   = 0;
+  pnode->nd_gpustatus = NULL;
+  pnode->nd_ngpustatus = 0;
 
   for (i = 0;pul[i];i++)
     {
@@ -998,13 +1003,12 @@ static int process_host_name_part(
 
   memcpy((char *)&addr, hp->h_addr, hp->h_length);
 
-  if (hp->h_addr_list[1] == NULL)
+  if (hp->h_addr_list[0] != NULL)
     {
-    /* weren't given canonical name */
 
     char *hname;
 
-    if ((hp = gethostbyaddr(
+/*    if ((hp = gethostbyaddr(
                 (void *) & addr,
                 sizeof(struct in_addr),
                 hp->h_addrtype)) == NULL)
@@ -1021,7 +1025,7 @@ static int process_host_name_part(
       phostname = NULL;
 
       return(PBSE_UNKNODE);
-      }
+      }*/
 
     hname = (char *)strdup(hp->h_name); /* canonical name in theory */
 
@@ -1426,9 +1430,9 @@ static struct pbssubn *create_subnode(
 
 /* recheck_for_node :
  * This function is called whenever an entry in the nodes file does
- * not resolve on server initialization. This function is called 
- * periodically to see if the node is now resolvable and if so 
- * add it to the list of available MOM nodes. */ 
+ * not resolve on server initialization. This function is called
+ * periodically to see if the node is now resolvable and if so
+ * add it to the list of available MOM nodes. */
 void recheck_for_node( struct work_task *ptask)
   {
   node_info *host_info;
@@ -1515,7 +1519,7 @@ int create_pbs_node(
       if(pattrl == NULL)
         {
         log_err(-1, "cannot create node attribute", log_buffer);
-        return(PBSE_SYSTEM);                    
+        return(PBSE_SYSTEM);
         }
 
       strcpy(pattrl->al_value, pal->al_atopl.value);
@@ -1540,7 +1544,7 @@ int create_pbs_node(
       strcpy(host_info->nodename, objname);
       }
 
-      
+
     set_task(WORK_Timed, time_now + 30 /*PBS_LOG_CHECK_RATE  five minutes */, recheck_for_node, host_info);
 
     return(rc);
@@ -1680,13 +1684,13 @@ int create_pbs_node(
 
 
 int create_a_gpusubnode(
-    
+
   struct pbsnode *pnode)
 
   {
   static char *id = "create_a_gpusubnode";
   struct gpusubn *tmp;
- 
+
   tmp = malloc(sizeof(struct gpusubn) * (1 + pnode->nd_ngpus));
 
   if (tmp == NULL)
@@ -1706,10 +1710,14 @@ int create_a_gpusubnode(
   pnode->nd_gpusn = tmp;
 
   /* initialize the node */
+  pnode->nd_gpus_real = FALSE;
   pnode->nd_gpusn[pnode->nd_ngpus].pjob = NULL;
-  pnode->nd_gpusn[pnode->nd_ngpus].inuse = FALSE;
+  pnode->nd_gpusn[pnode->nd_ngpus].inuse = 0;
+  pnode->nd_gpusn[pnode->nd_ngpus].mode = gpu_normal;
+  pnode->nd_gpusn[pnode->nd_ngpus].state = gpu_unallocated;
   pnode->nd_gpusn[pnode->nd_ngpus].flag = 0;
   pnode->nd_gpusn[pnode->nd_ngpus].index = pnode->nd_ngpus;
+  pnode->nd_gpusn[pnode->nd_ngpus].gpuid = NULL;
 
   /* increment the number of gpu subnodes and gpus free */
   pnode->nd_ngpus++;
@@ -1996,7 +2004,7 @@ int setup_nodes(void)
       int num_digits;
 
       start = atoi(open_bracket+1);
-      
+
       dash = strchr(open_bracket,'-');
       close_bracket = strchr(open_bracket,']');
 
@@ -2028,7 +2036,7 @@ int setup_nodes(void)
         int tmp = 10;
 
         strcpy(tmp_node_name,nodename);
-       
+
         /* determine the length of the number */
         while (start / tmp > 0)
           {
@@ -2252,9 +2260,9 @@ static void delete_a_subnode(
 
 
 
-/* 
+/*
  * deletes the last gpu subnode
- * frees the node and decrements the number to adjust 
+ * frees the node and decrements the number to adjust
  */
 static void delete_a_gpusubnode(
 
@@ -2398,8 +2406,8 @@ int node_gpus_action(
    only be a name for the new node and no attributes or properties */
 
 int create_partial_pbs_node(
-  char *nodename, 
-  unsigned long addr, 
+  char *nodename,
+  unsigned long addr,
   int perms)
 
   {
